# flake8: noqa

"""
    EMIL Number Generator Service

    The EMIL Number Generator Service API is a robust tool                  designed to generate unique and structured entity numbers                  like policies, accounts, invoices, and other entities.                  This API streamlines the process of creating distinct identifiers                  for various business objects.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


__version__ = "1.2.0"

# import ApiClient
from eis.numbergenerator.api_client import ApiClient

# import Configuration
from eis.numbergenerator.configuration import Configuration

# import exceptions
from eis.numbergenerator.exceptions import OpenApiException
from eis.numbergenerator.exceptions import ApiAttributeError
from eis.numbergenerator.exceptions import ApiTypeError
from eis.numbergenerator.exceptions import ApiValueError
from eis.numbergenerator.exceptions import ApiKeyError
from eis.numbergenerator.exceptions import ApiException
