"""
    EMIL Number Generator Service

    The EMIL Number Generator Service API is a robust tool                  designed to generate unique and structured entity numbers                  like policies, accounts, invoices, and other entities.                  This API streamlines the process of creating distinct identifiers                  for various business objects.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import eis.numbergenerator
from eis.numbergenerator.model.entity_number_class import EntityNumberClass


class TestEntityNumberClass(unittest.TestCase):
    """EntityNumberClass unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testEntityNumberClass(self):
        """Test EntityNumberClass"""
        # FIXME: construct object with mandatory attributes with example values
        # model = EntityNumberClass()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
