"""
    EMIL Number Generator Service

    The EMIL Number Generator Service API is a robust tool                  designed to generate unique and structured entity numbers                  like policies, accounts, invoices, and other entities.                  This API streamlines the process of creating distinct identifiers                  for various business objects.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.numbergenerator
from eis.numbergenerator.api.numbers_api import NumbersApi  # noqa: E501


class TestNumbersApi(unittest.TestCase):
    """NumbersApi unit test stubs"""

    def setUp(self):
        self.api = NumbersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_number(self):
        """Test case for create_number

        Create the number  # noqa: E501
        """
        pass

    def test_get_number(self):
        """Test case for get_number

        Retrieve the number  # noqa: E501
        """
        pass

    def test_list_numbers(self):
        """Test case for list_numbers

        List Numbers  # noqa: E501
        """
        pass

    def test_lookup_number(self):
        """Test case for lookup_number

        Lookup entity number  # noqa: E501
        """
        pass

    def test_reset_number(self):
        """Test case for reset_number

        Reset entity number  # noqa: E501
        """
        pass

    def test_update_number(self):
        """Test case for update_number

        Update the number  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
